<?php

/**
 * @file
 * BIPAA's theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template normally located in the
 * modules/system directory.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bipaa.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $hide_site_name: TRUE if the site name has been toggled off on the theme
 *   settings page. If hidden, the "element-invisible" class is added to make
 *   the site name visually hidden, but still accessible.
 * - $hide_site_slogan: TRUE if the site slogan has been toggled off on the
 *   theme settings page. If hidden, the "element-invisible" class is added to
 *   make the site slogan visually hidden, but still accessible.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['header']: Items for the header region.
 * - $page['featured']: Items for the featured region.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['triptych_first']: Items for the first triptych.
 * - $page['triptych_middle']: Items for the middle triptych.
 * - $page['triptych_last']: Items for the last triptych.
 * - $page['footer_firstcolumn']: Items for the first footer column.
 * - $page['footer_secondcolumn']: Items for the second footer column.
 * - $page['footer_thirdcolumn']: Items for the third footer column.
 * - $page['footer_fourthcolumn']: Items for the fourth footer column.
 * - $page['footer']: Items for the footer region.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 * @see bipaa_process_page()
 * @see html.tpl.php
 */

$feat_nav = "";
if (isset($node) && $node->type == "chado_feature") {
    // Links between mrna and proteins
    if ($node->feature->type_id->name == "mRNA" && isset($node->feature->all_relationships['object']['derives from']['polypeptide'][0]->record->subject_id->nid)) {
        $feat_nav = "You are viewing an mRNA, more information available on the corresponding ".l("polypeptide page", "node/".$node->feature->all_relationships['object']['derives from']['polypeptide'][0]->record->subject_id->nid);
    }
    else if ($node->feature->type_id->name == "polypeptide" && isset($node->feature->all_relationships['subject']['derives from']['mRNA'][0]->record->object_id->nid)) {
        $feat_nav = "You are viewing a polypeptide, more information available on the corresponding ".l("mRNA page", "node/".$node->feature->all_relationships['subject']['derives from']['mRNA'][0]->record->object_id->nid);
    }
}
?>
    <header id="masthead" class="site-header" role="banner">
        <a class="home-link" href="<?php echo $GLOBALS['base_url']; ?>" title="BIPAA" rel="home">
        </a>

        <div id="navbar" class="navbar">
            <nav id="site-navigation" class="navigation main-navigation" role="navigation">
                <button class="menu-toggle">Menu</button>
                <a class="screen-reader-text skip-link" href="#content" title="Skip to content">Skip to content</a>
                <div class="menu-main-container">
                    <ul id="primary-menu" class="nav-menu">
                        <?php if (getenv('ENABLE_ORTHOLOGY')): ?>
                            <li id="menu-item-44" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-44"><a href="<?php echo $GLOBALS['base_url']; ?>/search/phylotree">Gene families</a></li>
                            <li id="menu-item-44" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-44"><a href="<?php echo $GLOBALS['base_url']; ?>/chado/organism">Organisms</a></li>
                        <?php elseif (getenv('ENABLE_NO_CHADO_DATA')): ?>
                            <li id="menu-item-46" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-home menu-item-has-children menu-item-46"><a href="<?php echo $GLOBALS['base_url']; ?>">
                                <?php
                                    if (getenv('SITE_NAME'))
                                        echo getenv('SITE_NAME');
                                    else
                                        echo "Home";
                                ?>
                                </a>
                            </li>
                        <?php else: ?>
                            <li id="menu-item-46" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-home menu-item-has-children menu-item-46"><a href="<?php echo $GLOBALS['base_url']; ?>">
                                <?php
                                    if (getenv('SITE_NAME'))
                                        echo getenv('SITE_NAME');
                                    else
                                        echo "Home";
                                ?>
                                </a>
                                <ul class="sub-menu">
                                    <li id="menu-item-43" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-43"><a href="<?php echo $GLOBALS['base_url']; ?>/chado/analysis">Analyses</a></li>
                                    <li id="menu-item-44" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-44"><a href="<?php echo $GLOBALS['base_url']; ?>/chado/feature">Features</a></li>
                                    <li id="menu-item-44" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-44"><a href="<?php echo $GLOBALS['base_url']; ?>/chado/organism">Organisms</a></li>
                                    <!--li id="menu-item-44" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-44"><a href="<?php echo $GLOBALS['base_url']; ?>/elastic_search">Advanced search</a></li-->
                                </ul>
                            </li>
                        <?php endif; ?>
                        <?php if (getenv('ENABLE_GO')): ?>
                            <?php
                                if (getenv('ENABLE_GO') == "1")
                                    $url = '/organism/';
                                else
                                    $url = getenv('ENABLE_GO');
                            ?>
                            <li id="menu-item-46" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children menu-item-46"><a href="<?php echo $GLOBALS['base_url'].$url; ?>">GO Report</a></li>
                        <?php endif; ?>
                        <?php if (getenv('ENABLE_BLAST')): ?>
                            <?php
                                if (getenv('ENABLE_BLAST') == "1")
                                    $url = $GLOBALS['base_url'].'/blast';
                                else
                                    $url = getenv('ENABLE_BLAST');
                            ?>
                            <li id="menu-item-46" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children menu-item-46"><a href="<?php echo $url; ?>">Blast</a></li>
                        <?php endif; ?>
                        <?php if (getenv('ENABLE_JBROWSE')): ?>
                            <?php
                                if (getenv('ENABLE_JBROWSE') == "1")
                                    $url = '/jbrowse';
                                else
                                    $url = getenv('ENABLE_JBROWSE');
                            ?>
                            <li id="menu-item-46" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children menu-item-46"><a href="<?php echo $GLOBALS['base_url'].$url; ?>">JBrowse</a></li>
                        <?php endif; ?>
                        <?php if (getenv('ENABLE_APOLLO')): ?>
                            <?php
                                if (getenv('ENABLE_APOLLO') == "1")
                                    $url = '/apollo';
                                else
                                    $url = getenv('ENABLE_APOLLO');
                            ?>
                            <li id="menu-item-46" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children menu-item-46"><a href="<?php echo $GLOBALS['base_url'].$url; ?>">Apollo</a>
                                <ul class="sub-menu">
                                    <li id="menu-item-43" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-43"><a href="<?php echo $GLOBALS['base_url'].'/apollo_report'; ?>">Annotation report</a></li>
                                </ul>
                            </li>
                        <?php endif; ?>
                        <?php if (getenv('ENABLE_AUREME')): ?>
                            <?php
                                if (getenv('ENABLE_AUREME') == "1")
                                    $url = $GLOBALS['base_url'].'/aureme';
                                else
                                    $url = getenv('ENABLE_AUREME');
                            ?>
                            <li id="menu-item-46" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children menu-item-46"><a href="<?php echo $url; ?>">Metabolic model</a></li>
                        <?php endif; ?>
                        <?php if (getenv('ENABLE_WIKI')): ?>
                            <?php
                                if (getenv('ENABLE_WIKI') == "1")
                                    $url = $GLOBALS['base_url'].'/wiki/';
                                else
                                    $url = getenv('ENABLE_WIKI');
                            ?>
                            <li id="menu-item-46" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children menu-item-46"><a href="<?php echo $url; ?>">Wiki</a></li>
                        <?php endif; ?>
                        <?php if (getenv('ENABLE_DOWNLOAD')): ?>
                            <?php
                                if (getenv('ENABLE_DOWNLOAD') == "1")
                                    $url = '/download';
                                else
                                    $url = getenv('ENABLE_DOWNLOAD');
                            ?>
                            <li id="menu-item-46" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children menu-item-46"><a href="<?php echo $GLOBALS['base_url'].$url; ?>">Download</a></li>
                        <?php endif; ?>
                        <li id="menu-item-46" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children menu-item-46"><a href="http://bipaa.genouest.org/is/">BIPAA</a>
                            <ul class="sub-menu">
                                <li id="menu-item-43" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-43"><a href="https://bipaa.genouest.org/is/aphidbase/">AphidBase</a></li>
                                <li id="menu-item-44" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-44"><a href="https://bipaa.genouest.org/is/parwaspdb/">ParWaspDB</a></li>
                                <li id="menu-item-44" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-44"><a href="https://bipaa.genouest.org/is/parwaspdb/">ParWaspDB</a></li>
                                <li id="menu-item-78" class="menu-item menu-item-type-post_type menu-item-object-page menu-item-has-children menu-item-78"><a href="https://bipaa.genouest.org/is/lepidodb/">LepidoDB</a></li>
                                <li id="menu-item-66" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children menu-item-66"><a href="http://bipaa.genouest.org/data/">Downloads</a></li>
                                <li id="menu-item-130" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-130"><a href="https://bipaa-galaxy.genouest.org/">Galaxy</a></li>
                                <li id="menu-item-138" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-138"><a href="http://bipaa.genouest.org/account">BIPAA account</a></li>
                            </ul>
                        </li>
                    </ul>
                </div>
                <?php if (!getenv('ENABLE_ORTHOLOGY')): ?>
                    <?php print render($page['header']["tripal_elasticsearch_elasticsearch_website_search_box"]); ?>
                <?php endif; ?>
            </nav><!-- #site-navigation -->
        </div><!-- #navbar -->
    </header><!-- #masthead -->

    <div id="main" class="site-main">

        <div id="primary" class="content-area">
            <div id="content" class="site-content" role="main">
                <article class="page type-page status-publish hentry">



    <div class="entry-content">
      <?php if ($page['highlighted']): ?><div id="highlighted"><?php print render($page['highlighted']); ?></div><?php endif; ?>
      <a id="main-content"></a>
      <header class="entry-header">
          <?php print render($title_prefix); ?>
          <?php if ($title): ?>
            <h1 class="entry-title" id="page-title">
              <?php print $title; ?>
            </h1>
          <?php endif; ?>
          <?php if (!empty($feat_nav)): ?>
              <p class="feat_nav" id="feat_nav">
                  <?php print $feat_nav; ?>
              </p>
          <?php endif; ?>
          <?php print render($title_suffix); ?>
      </header>
      <?php if ($tabs): ?>
        <div class="tabs">
          <?php print render($tabs); ?>
        </div>
      <?php endif; ?>
      <?php print render($page['help']); ?>
      <?php if ($action_links): ?>
        <ul class="action-links">
          <?php print render($action_links); ?>
        </ul>
      <?php endif; ?>
      <?php print render($page['content']); ?>

    <?php if ($page['sidebar_second']): ?>
      <div id="sidebar-second" class="column sidebar"><div class="section">
        <?php print render($page['sidebar_second']); ?>
      </div></div> <!-- /.section, /#sidebar-second -->
    <?php endif; ?>



        </div><!-- #entry-content -->
      </article>
    </div><!-- #content -->
</div><!-- #primary -->

<div id="tertiary" class="sidebar-container" role="complementary">
    <div class="sidebar-inner">
      <div class="widget-area">
      </div><!-- .widget-area -->
    </div><!-- .sidebar-inner -->
    </div><!-- #tertiary -->

    </div><!-- #main -->
    <footer id="colophon" class="site-footer" role="contentinfo">
    <div id="secondary" class="sidebar-container" role="complementary">
    <div class="widget-area masonry" style="position: relative; height: 250px;">

        <aside id="meta-2" class="widget widget_meta masonry-brick" style="position: absolute; left: 248px; top: 0px;"><h3 class="widget-title">Links</h3>			<ul>
			<li><a href="<?php echo $GLOBALS['base_url']."/user" ?>">Log in</a></li>
			<li><a href="<?php echo $GLOBALS['base_url']."/rss.xml" ?>">Content <abbr title="Really Simple Syndication">RSS</abbr></a></li>
			<li><a href="https://bipaa.genouest.org/">BIPAA website</a></li>
		</aside>


      <aside id="text-4" class="widget widget_text masonry-brick" style="position: absolute; left: 496px; top: 0px;">
          <div class="textwidget"><img src="<?php echo $GLOBALS['base_url']."/".drupal_get_path('theme', 'bipaa');?>/images/bipaa/bipaa.png"></div>
      </aside>
    </div><!-- .widget-area -->
</div><!-- #secondary -->
